@@ -195,17 +195,20 @@ def find_module_name_from_path(path_py: Path):
 
     return path_py.stem
 
+def _get_filename_from_frame(frame):
+    return frame.f_code.co_filename
+
 
 def get_module_name(frame):
     """Get the full module name"""
-    module = inspect.getmodule(frame[0])
+    module = inspect.getmodule(frame)
     filename = None
     if module is not None:
         module_name = module.__name__
         if module_name in ("__main__", "<run_path>"):
-            filename = frame.filename
+            filename = _get_filename_from_frame(frame)
     else:
-        filename = frame.filename
+        filename = _get_filename_from_frame(frame)
 
     if filename is not None:
         module_name = find_module_name_from_path(Path(filename))
@@ -217,15 +220,26 @@ def get_module_name(frame):
     return module_name
 
 
-def get_name_calling_module(index_frame: int = 1):
-    try:
-        frame = inspect.stack()[index_frame]
-    except IndexError:
-        print("index_frame", index_frame)
-        print([frame[1] for frame in inspect.stack()])
-        raise
+def get_name_calling_module():
+    return get_module_name(get_frame(1))
 
-    return get_module_name(frame)
+
+def get_frame(depth=1):
+    """Return a frame object from the call stack.
+
+    This should be equivalent to ``inspect.currentframe().f_back`` with ``depth``
+    times ``.f_back``. For example, ``depth = 1`` gives the caller frame.
+    """
+    try:
+        return sys._getframe(depth+1)
+    except AttributeError:
+        # we might want to implement this with another function
+        # (``inspect.currentframe`` or ``inspect.stack()``)
+        # for alternative Python implementations
+        raise
+    except ValueError:
+        print([frame_info[1] for frame_info in inspect.stack()])
+        raise
 
 
 def get_source_without_decorator(func: Callable):
